==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/emoticons/translations/emoticons_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Obličeje</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Povolit obličeje</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Pohybovat obličeji</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Podoba ikon</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Vybrat podobu výrazů obličeje</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Nainstalovat nové obličeje...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Archiv s motivem ikon</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Instalace se nezdařila</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archiv (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Vložit obličej</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Vložit obličej</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Vložit obličej - povolit v nastavení</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/emoticons/translations/emoticons_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Obličeje</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Povolit obličeje</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Pohybovat obličeji</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Podoba ikon</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Vybrat podobu výrazů obličeje</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Nainstalovat nové obličeje...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Archiv s motivem ikon</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Instalace se nezdařila</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archiv (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Vložit obličej</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Vložit obličej</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Vložit obličej - povolit v nastavení</translation>
    </message>
</context>
</TS>
